@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineResMeta;
 
-our $DATE = '2019-08-14'; # DATE
-our $VERSION = '0.819'; # VERSION
+our $DATE = '2020-04-29'; # DATE
+our $VERSION = '0.820'; # VERSION
 
 use 5.010;
 use strict;
@@ -88,7 +88,7 @@ Perinci::Examples::CmdLineResMeta - Functions in this package contains cmdline.*
 
 =head1 VERSION
 
-This document describes version 0.819 of Perinci::Examples::CmdLineResMeta (from Perl distribution Perinci-Examples), released on 2019-08-14.
+This document describes version 0.820 of Perinci::Examples::CmdLineResMeta (from Perl distribution Perinci-Examples), released on 2020-04-29.
 
 =head1 FUNCTIONS
 
@@ -159,6 +159,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<str>* => I<str>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -205,7 +206,7 @@ Usage:
 
  skip_format() -> [status, msg, payload, meta]
 
-Set cmdline.skip_format => 1.
+Set cmdline.skip_format =E<gt> 1.
 
 This function is not exported.
 
@@ -244,7 +245,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
